@@ -130,7 +130,8 @@ class Speaker(caching.base.CachingMixin,models.Model):
         Dialog.objects.bulk_create([ Dialog(Speaker=self,Number=d) for d in dialogs])
 
     def analyze(self,form):
-        words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker').filter(WordType__Label__regex = '^[^{<]').filter(Dialog__Speaker=self)
+        words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker')
+        words = words.filter(WordType__Label__regex = '^[^{<]').filter(Dialog__Speaker=self)
         #words = words.filter(WordType__CVSkel='CVC')
         #words = words.filter(WordType__Label__in = GOOD_WORDS)
         #words = words.filter(WordType__StressVowel__in = MONOPHTHONGS)
@@ -948,6 +949,8 @@ class WordToken(caching.base.CachingMixin,models.Model):
     def isAcceptable(self):
         if self.nextToPause():
             return False
+        if len(self.WordType.getCVSkel()) < 2:
+            return False
         return True
 
     def getAnalysisLines(self,output_form):
